# Uncomment the following RPM macro if you use a prerelease version:
%global prerelease alpha1
%global commit 1834c22bb88dc39bed8233d6641daa50036cb13c

Name: bup
Version: 0.28
Release: 0.3%{?prerelease:.%{prerelease}}%{?dist}
Summary: Very efficient backup system based on the git packfile format

# all of the code is licensed as GNU Lesser General Public License v2, except:
# - lib/bup/bupsplit.c: BSD License (two clause),
# - lib/bup/bupsplit.h: BSD License (two clause),
# - lib/bup/options.py: BSD License (two clause),
# - definition of relpath() function in wvtest.py: Python License
License: LGPLv2 and BSD and Python
URL: https://bup.github.io/
Source0: https://github.com/tjanez/%{name}/archive/%{commit}/%{name}-%{commit}.tar.gz

BuildRequires: python2-devel
BuildRequires: git
# Required for building documentation
BuildRequires: pandoc

Requires: git
Requires: pyxattr
Requires: pylibacl
# Only required for 'bup fuse' command
Requires: fuse-python
# Only required for 'bup web' command
Requires: python-tornado


%description
Very efficient backup system based on the git packfile format, providing fast
incremental saves and global deduplication (among and within files, including
virtual machine images). Some of its features are:
* It uses a rolling checksum algorithm and hence it can backup huge files
  incrementally.
* It uses packfile format from git, so one can access the stored data even if
  he doesn't like bup's user interface.
* It writes packfiles directly so it is fast even with huge amounts of data:
  it can track millions of files and keep track of hundreds or thousands of
  gigabytes of objects.
* Data is "automagically" shared between incremental backups without having to
  know which backup is based on which other one.
* One can make a backup directly to a remote bup server, without needing tons
  of temporary disk space on the computer being backed up. If the backup is
  interrupted halfway through, the next run will pick up where the previous
  backup left off.
* It can use "par2" redundancy to recover corrupted backups even if the disk
  has undetected bad sectors.
* Each incremental backup acts as if it's a full backup, it just takes less
  disk space.
* One can mount a bup repository as a FUSE filesystem and access the contents
  that way, or even export it over Samba.


%prep
%autosetup -n %{name}-%{commit} -S git


%build
# NOTE: bup uses a non-standard configure script which is executed during the
# execution of the make command.
# To configure the build process, we need to pass variables to the make
# command.
make %{?_smp_mflags} CFLAGS="${CFLAGS:-%optflags}" PYTHON=%{__python2}


%install
# NOTE: bup uses a non-standard configure script, which doesn't support
# specifying distro-specific paths of the variables defined below.
# To set the paths, we need to manually pass variables to the make command.
make install MANDIR=%{buildroot}%{_mandir} \
    DOCDIR=%{buildroot}%{_docdir}/{%name} BINDIR=%{buildroot}%{_bindir} \
    LIBDIR=%{buildroot}%{_libdir}/%{name} PYTHON=%{__python2}

# Fix hard-coded libdir location in bup's executable
sed -i 's|/lib/bup|/%{_lib}/bup|' %{buildroot}%{_bindir}/bup

# Remove bup's HTML documentation
rm -rf %{buildroot}%{_datadir}/doc


%check
# Run the built-in test suite containing 3800+ tests
# (it takes < 100 seconds on a modern computer)
make test PYTHON=%{__python2}


%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}
%{_libdir}/%{name}/
%{_mandir}/man1/%{name}.1*
%{_mandir}/man1/%{name}-*.1*


%changelog
* Tue Jun 30 2015 Tadej Janež <tadej.j@nez.si> 0.28-0.3.alpha1
- Updated to version with patch to check for saved_errors in every test.

* Tue Jun 30 2015 Tadej Janež <tadej.j@nez.si> 0.28-0.1.alpha1
- New package built with Tito.

* Tue Jun 30 2015 Tadej Janež <tadej.j@nez.si> 0.28-0.0.alpha1
- Test build of a prerelease version.

* Sun May 17 2015 Tadej Janež <tadej.j@nez.si> 0.27-0.1
- Initial package.
